@@ -598,7 +598,11 @@ void cs_fill_path_info(struct cs_path_info *ptr)
 	const int len = strlen(name);
 	ptr->total_len = len;
 	ptr->const_len = cs_const_part_length(name);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 8, 0)
+	ptr->hash = full_name_hash(NULL, name, len);
+#else
 	ptr->hash = full_name_hash(name, len);
+#endif
 }
 
 /**
